@@ -1,8 +1,7 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.26;
 use warnings;
-use 5.010;
 
 use Tickit::Async;
 use Tickit::Console;
